==> HinemosWebClient_src-2.0.0.tar.gz: HinemosWebClient_src-2.0.0/src/com/necsoft/hinemos/webclient/jobmanagement/util/JobPropertyUtil.java <==
/*
 
Copyright (C) NEC Corporation 2012. All Rights Reserved. 
Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.necsoft.hinemos.webclient.jobmanagement.util;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Locale;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import com.clustercontrol.jobmanagement.bean.HistoryFilterPropertyConstant;
import com.clustercontrol.jobmanagement.bean.JobOperationConstant;
import com.clustercontrol.jobmanagement.bean.OperationConstant;
import com.clustercontrol.ws.jobmanagement.HinemosUnknown_Exception;
import com.clustercontrol.ws.jobmanagement.InvalidRole_Exception;
import com.clustercontrol.ws.jobmanagement.JobEndStatusInfo;
import com.clustercontrol.ws.jobmanagement.JobHistoryFilter;
import com.clustercontrol.ws.jobmanagement.JobInfo;
import com.clustercontrol.ws.jobmanagement.JobManagementUserInfo;
import com.clustercontrol.ws.jobmanagement.JobMasterNotFound_Exception;
import com.clustercontrol.ws.jobmanagement.JobNotificationsInfo;
import com.clustercontrol.ws.jobmanagement.JobParameterInfo;
import com.clustercontrol.ws.jobmanagement.JobTreeItem;
import com.clustercontrol.ws.jobmanagement.NodeOperationInfo;
import com.clustercontrol.ws.jobmanagement.NotifyNotFound_Exception;
import com.clustercontrol.ws.jobmanagement.UserNotFound_Exception;
import com.necsoft.hinemos.webclient.bean.JobTriggerTypeConstant;
import com.necsoft.hinemos.webclient.bean.Property;
import com.necsoft.hinemos.webclient.bean.StatusConstant;
import com.necsoft.hinemos.webclient.util.EndpointManager;
import com.necsoft.hinemos.webclient.util.PropertyUtil;

public class JobPropertyUtil {
	// ログ
	private static Log m_log = LogFactory.getLog( JobPropertyUtil.class );

	public static NodeOperationInfo property2nodeOperation (Property property) {
		NodeOperationInfo info = new NodeOperationInfo();

		//セッションID取得
		ArrayList values = PropertyUtil.getPropertyValue(property, JobOperationConstant.SESSION);
		if(values.get(0) instanceof String && ((String)values.get(0)).length() > 0)
			info.setSessionId((String)values.get(0));

		//ジョブユニットID取得
		values = PropertyUtil.getPropertyValue(property, JobOperationConstant.JOB_UNIT);
		if(values.get(0) instanceof String && ((String)values.get(0)).length() > 0)
			info.setJobunitId((String)values.get(0));

		//ジョブID取得
		values = PropertyUtil.getPropertyValue(property, JobOperationConstant.JOB);
		if(values.get(0) instanceof String && ((String)values.get(0)).length() > 0)
			info.setJobId((String)values.get(0));

		//ファシリティID取得
		values = PropertyUtil.getPropertyValue(property, JobOperationConstant.FACILITY);
		if(values.size() > 0 && values.get(0) instanceof String && ((String)values.get(0)).length() > 0)
			info.setFacilityId((String)values.get(0));

		//制御取得
		values = PropertyUtil.getPropertyValue(property, JobOperationConstant.CONTROL);
		Integer control = null;
		if(values.get(0) instanceof String){
			String controlString = (String)values.get(0);
			control = Integer.valueOf(OperationConstant.stringToType(controlString));
			info.setControl(control);
		}

		//終了値取得
		values = PropertyUtil.getPropertyValue(property, JobOperationConstant.END_VALUE);
		if(values.size() > 0 && values.get(0) instanceof Integer)
			info.setEndValue((Integer)values.get(0));

		return info;
	}

	public static JobHistoryFilter property2jobHistoryFilter (Property property, Locale locale) {
		JobHistoryFilter filter = new JobHistoryFilter();
		ArrayList values = null;

		//開始・再実行日時（自）取得
		values = PropertyUtil.getPropertyValue(property, HistoryFilterPropertyConstant.START_FROM_DATE);
		if(values.get(0) != null && values.get(0) instanceof Date){
			filter.setStartFromDate(((Date)values.get(0)).getTime());
		}
		//開始・再実行日時（至）取得
		values = PropertyUtil.getPropertyValue(property, HistoryFilterPropertyConstant.START_TO_DATE);
		if(values.get(0) != null && values.get(0) instanceof Date){
			filter.setStartToDate(((Date)values.get(0)).getTime());
		}
		//終了・中断日時（自）取得
		values = PropertyUtil.getPropertyValue(property, HistoryFilterPropertyConstant.END_FROM_DATE);
		if(values.get(0) != null && values.get(0) instanceof Date){
			filter.setEndFromDate(((Date)values.get(0)).getTime());
		}
		//終了・中断日時（至）取得
		values = PropertyUtil.getPropertyValue(property, HistoryFilterPropertyConstant.END_TO_DATE);
		if(values.get(0) != null && values.get(0) instanceof Date){
			filter.setEndToDate(((Date)values.get(0)).getTime());
		}

		//ジョブID取得
		values = PropertyUtil.getPropertyValue(property, HistoryFilterPropertyConstant.JOB_ID);
		if(values.get(0) instanceof JobTreeItem){
			filter.setJobId(((JobTreeItem)values.get(0)).getData().getId());
		}
		else if(values.get(0) instanceof String && ((String)values.get(0)).length() > 0){
			filter.setJobId((String)values.get(0));
		}

		//状態取得
		values = PropertyUtil.getPropertyValue(property, HistoryFilterPropertyConstant.STATUS);
		Integer status = null;
		if(values.get(0) instanceof String){
			String statusString = (String)values.get(0);
			status = Integer.valueOf(StatusConstant.stringToType(statusString, locale));
			filter.setStatus(status);
		}

		//実行契機種別取得
		values = PropertyUtil.getPropertyValue(property, HistoryFilterPropertyConstant.TRIGGER_TYPE);
		Integer triggerType = null;
		if(values.get(0) instanceof String){
			String triggerTypeString = (String)values.get(0);
			triggerType = Integer.valueOf(JobTriggerTypeConstant.stringToType(triggerTypeString, locale));
			filter.setTriggerType(triggerType);
		}

		//実行契機情報取得
		values = PropertyUtil.getPropertyValue(property, HistoryFilterPropertyConstant.TRIGGER_INFO);
		String triggerInfo = null;
		if(!"".equals(values.get(0))) {
			triggerInfo = (String) values.get(0);
			filter.setTriggerInfo(triggerInfo);
		}
		return filter;
	}

	/**
	 * ジョブツリーを全てFullにする。
	 * 負荷が高いので取り扱い注意。
	 * @param jobTreeItem
	 */
	public static void setJobFullTree (JobTreeItem jobTreeItem, EndpointManager endpointManager) {
		setJobFull(jobTreeItem.getData(), endpointManager);
		List<JobTreeItem> children = jobTreeItem.getChildren();
		if (children == null) {
			return;
		}
		for (JobTreeItem child : children) {
			setJobFullTree(child, endpointManager);
		}
	}

	/**
	 * マネージャへアクセスするため、むやみに呼ばないこと。
	 * @param jobInfo
	 */
	public static void setJobFull (JobInfo jobInfo, EndpointManager endpointManager) {
		if (jobInfo.isPropertyFull()) {
			return;
		}
		if (jobInfo.getId() == null || "".equals(jobInfo.getId())) {
			return;
		}

		JobInfo ret = null;
		try {
			ret = JobEndpointWrapper.getJobFull(jobInfo, endpointManager);
		} catch (JobMasterNotFound_Exception e) {
			m_log.warn("setJobFull(), " + e.getMessage(), e);
			// 新ジョブの場合は、必ず通る。
			return;
		} catch (NotifyNotFound_Exception e) {
			m_log.warn("setJobFull() getJobFull, " + e.getMessage(), e);
			return;
		} catch (UserNotFound_Exception e) {
			m_log.warn("setJobFull() getJobFull, " + e.getMessage(), e);
			return;
		} catch (HinemosUnknown_Exception e) {
			m_log.warn("setJobFull() getJobFull, " + e.getMessage(), e);
			return;
		} catch (InvalidRole_Exception e) {
			m_log.warn("setJobFull() getJobFull, " + e.getMessage(), e);
			return;
		} catch (Exception e) {
			//メッセージを入れる必要があるか検討
			m_log.warn("setJobFull() getJobFull, " + e.getMessage(), e);
		} 

		jobInfo.setCommand(ret.getCommand());
		jobInfo.setCreateTime(ret.getCreateTime());
		jobInfo.setCreateUser(ret.getCreateUser());
		jobInfo.setDescription(ret.getDescription());
		List<JobEndStatusInfo> jobEndStatusInfoList = jobInfo.getEndStatus();
		jobEndStatusInfoList.clear();
		if (ret.getEndStatus() != null) {
			jobEndStatusInfoList.addAll(ret.getEndStatus());
		}
		jobInfo.setFile(ret.getFile());
		// jobInfo.setId(ret.getId());
		// jobInfo.setJobunitId(ret.getJobunitId());
		List<JobManagementUserInfo> jobManagementUserInfoList = jobInfo.getManagementUser();
		jobManagementUserInfoList.clear();
		if (ret.getManagementUser() != null) {
			jobManagementUserInfoList.addAll(ret.getManagementUser());
		}
		// jobInfo.setName(ret.getName());
		List<JobNotificationsInfo> jobNotificationsInfoList = jobInfo.getNotifications();
		jobNotificationsInfoList.clear();
		if (ret.getNotifications() != null) {
			jobNotificationsInfoList.addAll(ret.getNotifications());
		}
		List<JobParameterInfo> jobParameterInfoList = jobInfo.getParam();
		jobParameterInfoList.clear();
		if (ret.getParam() != null) {
			jobParameterInfoList.addAll(ret.getParam());
		}
		jobInfo.setPropertyFull(true);
		jobInfo.setType(ret.getType());
		jobInfo.setUpdateTime(ret.getUpdateTime());
		jobInfo.setUpdateUser(ret.getUpdateUser());
		jobInfo.setWaitRule(ret.getWaitRule());
	}
}

==> HinemosWebClient_src-2.0.1.tar.gz: HinemosWebClient_src-2.0.1/src/com/necsoft/hinemos/webclient/jobmanagement/util/JobPropertyUtil.java <==
/*
 
Copyright (C) NEC Corporation 2012-2013. All Rights Reserved. 
Copyright (C) NEC Soft, Ltd. 2012-2013. All Rights Reserved. 
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.necsoft.hinemos.webclient.jobmanagement.util;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Locale;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.clustercontrol.jobmanagement.bean.HistoryFilterPropertyConstant;
import com.clustercontrol.jobmanagement.bean.JobOperationConstant;
import com.clustercontrol.ws.jobmanagement.HinemosUnknown_Exception;
import com.clustercontrol.ws.jobmanagement.InvalidRole_Exception;
import com.clustercontrol.ws.jobmanagement.JobEndStatusInfo;
import com.clustercontrol.ws.jobmanagement.JobHistoryFilter;
import com.clustercontrol.ws.jobmanagement.JobInfo;
import com.clustercontrol.ws.jobmanagement.JobManagementUserInfo;
import com.clustercontrol.ws.jobmanagement.JobMasterNotFound_Exception;
import com.clustercontrol.ws.jobmanagement.JobNotificationsInfo;
import com.clustercontrol.ws.jobmanagement.JobParameterInfo;
import com.clustercontrol.ws.jobmanagement.JobTreeItem;
import com.clustercontrol.ws.jobmanagement.NodeOperationInfo;
import com.clustercontrol.ws.jobmanagement.NotifyNotFound_Exception;
import com.clustercontrol.ws.jobmanagement.UserNotFound_Exception;
import com.necsoft.hinemos.webclient.bean.JobTriggerTypeConstant;
import com.necsoft.hinemos.webclient.bean.Property;
import com.necsoft.hinemos.webclient.bean.StatusConstant;
import com.necsoft.hinemos.webclient.jobmanagement.bean.OperationConstant;
import com.necsoft.hinemos.webclient.util.EndpointManager;
import com.necsoft.hinemos.webclient.util.PropertyUtil;

public class JobPropertyUtil {
	// ログ
	private static Log m_log = LogFactory.getLog( JobPropertyUtil.class );

	public static NodeOperationInfo property2nodeOperation (Property property) {
		NodeOperationInfo info = new NodeOperationInfo();

		//セッションID取得
		ArrayList values = PropertyUtil.getPropertyValue(property, JobOperationConstant.SESSION);
		if(values.get(0) instanceof String && ((String)values.get(0)).length() > 0)
			info.setSessionId((String)values.get(0));

		//ジョブユニットID取得
		values = PropertyUtil.getPropertyValue(property, JobOperationConstant.JOB_UNIT);
		if(values.get(0) instanceof String && ((String)values.get(0)).length() > 0)
			info.setJobunitId((String)values.get(0));

		//ジョブID取得
		values = PropertyUtil.getPropertyValue(property, JobOperationConstant.JOB);
		if(values.get(0) instanceof String && ((String)values.get(0)).length() > 0)
			info.setJobId((String)values.get(0));

		//ファシリティID取得
		values = PropertyUtil.getPropertyValue(property, JobOperationConstant.FACILITY);
		if(values.size() > 0 && values.get(0) instanceof String && ((String)values.get(0)).length() > 0)
			info.setFacilityId((String)values.get(0));

		//制御取得
		values = PropertyUtil.getPropertyValue(property, JobOperationConstant.CONTROL);
		Integer control = null;
		if(values.get(0) instanceof String){
			String controlString = (String)values.get(0);
			control = Integer.valueOf(OperationConstant.stringToType(controlString));
			info.setControl(control);
		}

		//終了値取得
		values = PropertyUtil.getPropertyValue(property, JobOperationConstant.END_VALUE);
		if(values.size() > 0 && values.get(0) instanceof Integer)
			info.setEndValue((Integer)values.get(0));

		return info;
	}

	public static JobHistoryFilter property2jobHistoryFilter (Property property, Locale locale) {
		JobHistoryFilter filter = new JobHistoryFilter();
		ArrayList values = null;

		//開始・再実行日時（自）取得
		values = PropertyUtil.getPropertyValue(property, HistoryFilterPropertyConstant.START_FROM_DATE);
		if(values.get(0) != null && values.get(0) instanceof Date){
			filter.setStartFromDate(((Date)values.get(0)).getTime());
		}
		//開始・再実行日時（至）取得
		values = PropertyUtil.getPropertyValue(property, HistoryFilterPropertyConstant.START_TO_DATE);
		if(values.get(0) != null && values.get(0) instanceof Date){
			filter.setStartToDate(((Date)values.get(0)).getTime());
		}
		//終了・中断日時（自）取得
		values = PropertyUtil.getPropertyValue(property, HistoryFilterPropertyConstant.END_FROM_DATE);
		if(values.get(0) != null && values.get(0) instanceof Date){
			filter.setEndFromDate(((Date)values.get(0)).getTime());
		}
		//終了・中断日時（至）取得
		values = PropertyUtil.getPropertyValue(property, HistoryFilterPropertyConstant.END_TO_DATE);
		if(values.get(0) != null && values.get(0) instanceof Date){
			filter.setEndToDate(((Date)values.get(0)).getTime());
		}

		//ジョブID取得
		values = PropertyUtil.getPropertyValue(property, HistoryFilterPropertyConstant.JOB_ID);
		if(values.get(0) instanceof JobTreeItem){
			filter.setJobId(((JobTreeItem)values.get(0)).getData().getId());
		}
		else if(values.get(0) instanceof String && ((String)values.get(0)).length() > 0){
			filter.setJobId((String)values.get(0));
		}

		//状態取得
		values = PropertyUtil.getPropertyValue(property, HistoryFilterPropertyConstant.STATUS);
		Integer status = null;
		if(values.get(0) instanceof String){
			String statusString = (String)values.get(0);
			status = Integer.valueOf(StatusConstant.stringToType(statusString));
			filter.setStatus(status);
		}

		//実行契機種別取得
		values = PropertyUtil.getPropertyValue(property, HistoryFilterPropertyConstant.TRIGGER_TYPE);
		Integer triggerType = null;
		if(values.get(0) instanceof String){
			String triggerTypeString = (String)values.get(0);
			triggerType = Integer.valueOf(JobTriggerTypeConstant.stringToType(triggerTypeString));
			filter.setTriggerType(triggerType);
		}

		//実行契機情報取得
		values = PropertyUtil.getPropertyValue(property, HistoryFilterPropertyConstant.TRIGGER_INFO);
		String triggerInfo = null;
		if(!"".equals(values.get(0))) {
			triggerInfo = (String) values.get(0);
			filter.setTriggerInfo(triggerInfo);
		}
		return filter;
	}

	/**
	 * ジョブツリーを全てFullにする。
	 * 負荷が高いので取り扱い注意。
	 * @param jobTreeItem
	 */
	public static void setJobFullTree (JobTreeItem jobTreeItem, EndpointManager endpointManager) {
		setJobFull(jobTreeItem.getData(), endpointManager);
		List<JobTreeItem> children = jobTreeItem.getChildren();
		if (children == null) {
			return;
		}
		for (JobTreeItem child : children) {
			setJobFullTree(child, endpointManager);
		}
	}

	/**
	 * マネージャへアクセスするため、むやみに呼ばないこと。
	 * @param jobInfo
	 */
	public static void setJobFull (JobInfo jobInfo, EndpointManager endpointManager) {
		if (jobInfo.isPropertyFull()) {
			return;
		}
		if (jobInfo.getId() == null || "".equals(jobInfo.getId())) {
			return;
		}

		JobInfo ret = null;
		try {
			ret = JobEndpointWrapper.getJobFull(jobInfo, endpointManager);
		} catch (JobMasterNotFound_Exception e) {
			m_log.warn("setJobFull(), " + e.getMessage(), e);
			// 新ジョブの場合は、必ず通る。
			return;
		} catch (NotifyNotFound_Exception e) {
			m_log.warn("setJobFull() getJobFull, " + e.getMessage(), e);
			return;
		} catch (UserNotFound_Exception e) {
			m_log.warn("setJobFull() getJobFull, " + e.getMessage(), e);
			return;
		} catch (HinemosUnknown_Exception e) {
			m_log.warn("setJobFull() getJobFull, " + e.getMessage(), e);
			return;
		} catch (InvalidRole_Exception e) {
			m_log.warn("setJobFull() getJobFull, " + e.getMessage(), e);
			return;
		} catch (Exception e) {
			//メッセージを入れる必要があるか検討
			m_log.warn("setJobFull() getJobFull, " + e.getMessage(), e);
		} 

		jobInfo.setCommand(ret.getCommand());
		jobInfo.setCreateTime(ret.getCreateTime());
		jobInfo.setCreateUser(ret.getCreateUser());
		jobInfo.setDescription(ret.getDescription());
		List<JobEndStatusInfo> jobEndStatusInfoList = jobInfo.getEndStatus();
		jobEndStatusInfoList.clear();
		if (ret.getEndStatus() != null) {
			jobEndStatusInfoList.addAll(ret.getEndStatus());
		}
		jobInfo.setFile(ret.getFile());
		// jobInfo.setId(ret.getId());
		// jobInfo.setJobunitId(ret.getJobunitId());
		List<JobManagementUserInfo> jobManagementUserInfoList = jobInfo.getManagementUser();
		jobManagementUserInfoList.clear();
		if (ret.getManagementUser() != null) {
			jobManagementUserInfoList.addAll(ret.getManagementUser());
		}
		// jobInfo.setName(ret.getName());
		List<JobNotificationsInfo> jobNotificationsInfoList = jobInfo.getNotifications();
		jobNotificationsInfoList.clear();
		if (ret.getNotifications() != null) {
			jobNotificationsInfoList.addAll(ret.getNotifications());
		}
		List<JobParameterInfo> jobParameterInfoList = jobInfo.getParam();
		jobParameterInfoList.clear();
		if (ret.getParam() != null) {
			jobParameterInfoList.addAll(ret.getParam());
		}
		jobInfo.setPropertyFull(true);
		jobInfo.setType(ret.getType());
		jobInfo.setUpdateTime(ret.getUpdateTime());
		jobInfo.setUpdateUser(ret.getUpdateUser());
		jobInfo.setWaitRule(ret.getWaitRule());
	}
}
